@@ -1,14 +1,14 @@
 # -*- coding: utf8 -*-
-from django.contrib.auth import get_user_model
 from django.utils import unittest
+from basis.utils import User
 from .models import Person
 
 
 class TestLoginCodes(unittest.TestCase):
 
     def setUp(self):
-        self.user1 = get_user_model().objects.get_or_create(username="test1")[0]
-        self.user2 = get_user_model().objects.get_or_create(username="test2")[0]
+        self.user1 = User.objects.get_or_create(username="test1")[0]
+        self.user2 = User.objects.get_or_create(username="test2")[0]
 
     def tearDown(self):
         self.user1.delete()
@@ -55,4 +55,4 @@ class TestLoginCodes(unittest.TestCase):
         self.assertEqual(Person.all_objects.all().count(), 1)
 
         person.restore()
-        self.assertEqual(Person.objects.all().count(), 1)
\ No newline at end of file
+        self.assertEqual(Person.objects.all().count(), 1)
